@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/SharedMem.pm
-## Version v0.3.2
+## Version v0.3.3
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/01/18
-## Modified 2022/07/29
+## Modified 2022/08/05
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -109,7 +109,7 @@ EOT
             lock    => [qw( LOCK_EX LOCK_SH LOCK_NB LOCK_UN )],
             'flock' => [qw( LOCK_EX LOCK_SH LOCK_NB LOCK_UN )],
     );
-    our $VERSION = 'v0.3.2';
+    our $VERSION = 'v0.3.3';
 };
 
 # use strict;
@@ -1013,7 +1013,8 @@ sub FREEZE
     my %hash  = %$self;
     CORE::delete( @hash{ qw( addr id locked owner removed removed_semaphore semid ) } );
     # Return an array reference rather than a list so this works with Sereal and CBOR
-    CORE::return( [$class, \%hash] ) if( $serialiser eq 'Sereal' || $serialiser eq 'CBOR' );
+    # On or before Sereal version 4.023, Sereal did not support multiple values returned
+    CORE::return( [$class, \%hash] ) if( $serialiser eq 'Sereal' && Sereal::Encoder->VERSION <= version->parse( '4.023' ) );
     # But Storable want a list with the first element being the serialised element
     CORE::return( $class, \%hash );
 }
@@ -1134,7 +1135,8 @@ END
         my $class = CORE::ref( $self );
         my @array = @$self;
         # Return an array reference rather than a list so this works with Sereal
-        CORE::return( [$class, \@array] ) if( $serialiser eq 'Sereal' );
+        # On or before Sereal version 4.023, Sereal did not support multiple values returned
+        CORE::return( [$class, \@array] ) if( $serialiser eq 'Sereal' && Sereal::Encoder->VERSION <= version->parse( '4.023' ) );
         # But CBOR and Storable want a list with the first element being the serialised element
         CORE::return( $class, \@array );
     }
@@ -1226,7 +1228,8 @@ END
         my $class = CORE::ref( $self );
         my @array = @$self;
         # Return an array reference rather than a list so this works with Sereal
-        CORE::return( [$class, \@array] ) if( $serialiser eq 'Sereal' );
+        # On or before Sereal version 4.023, Sereal did not support multiple values returned
+        CORE::return( [$class, \@array] ) if( $serialiser eq 'Sereal' && Sereal::Encoder->VERSION <= version->parse( '4.023' ) );
         # But CBOR and Storable want a list with the first element being the serialised element
         CORE::return( $class, \@array );
     }
